@@ -213,6 +213,7 @@ def base_honeybee_osw(
                         json.dump(geo_dict, fp, indent=4)
 
             # if the DES system is GSHP, specify any autocalculated ground temperatures
+            dead_band = 8  # minimum annual delta T of the ground GHEDesigner needs
             with open(sys_param_file, 'r') as spf:
                 sys_dict = json.load(spf)
             if 'district_system' in sys_dict:
@@ -222,8 +223,19 @@ def base_honeybee_osw(
                         soil_par = g5_par['soil']
                         if soil_par['undisturbed_temp'] == 'Autocalculate':
                             epw_obj = EPW(epw_file)
-                            soil_par['undisturbed_temp'] = \
-                                epw_obj.dry_bulb_temperature.average
+                            start_temp = epw_obj.dry_bulb_temperature.average
+                            if 'ghe_parameters' in g5_par and \
+                                    'design' in g5_par['ghe_parameters']:
+                                design = g5_par['ghe_parameters']['design']
+                                if 'min_eft' in design and \
+                                        design['min_eft'] + dead_band > start_temp:
+                                    # ground is too cold
+                                    start_temp = design['min_eft'] + dead_band
+                                elif 'max_eft' in design and \
+                                        design['max_eft'] - dead_band < start_temp:
+                                    # ground is too hot
+                                    start_temp = design['max_eft'] - dead_band
+                            soil_par['undisturbed_temp'] = start_temp
                             with open(sys_param_file, 'w') as fp:
                                 json.dump(sys_dict, fp, indent=4)
 
@@ -561,20 +573,15 @@ def run_des_sys_param(feature_geojson, scenario_csv):
         des_par = sp_dict['district_system']['fifth_generation']
         des_par['horizontal_piping_parameters'] = \
             original_des_par['horizontal_piping_parameters']
+        des_par['central_pump_parameters'] = original_des_par['central_pump_parameters']
         des_par['soil'] = original_des_par['soil']
         des_par['ghe_parameters']['fluid'] = original_ghe_par['fluid']
         des_par['ghe_parameters']['grout'] = original_ghe_par['grout']
         des_par['ghe_parameters']['pipe'] = original_ghe_par['pipe']
         des_par['ghe_parameters']['design'] = original_ghe_par['design']
         des_par['ghe_parameters']['simulation'] = original_ghe_par['simulation']
-        des_par['ghe_parameters']['geometric_constraints'] = \
-            original_ghe_par['geometric_constraints']
-        des_par['ghe_parameters']['ghe_specific_params'] = \
-            original_ghe_par['ghe_specific_params']
-        # remove geometric params so that ThermalNetwork uses GeoJSON polygon
-        rect_geo_par = []
-        for ghe_dict in des_par['ghe_parameters']['ghe_specific_params']:
-            rect_geo_par.append(ghe_dict.pop('ghe_geometric_params'))
+        des_par['ghe_parameters']['borehole'] = original_ghe_par['borehole']
+        des_par['ghe_parameters']['borefields'] = original_ghe_par['borefields']
     else:
         sp_dict['district_system'] = des_dict
     with open(sys_param_file, 'w') as spf:
@@ -592,6 +599,7 @@ def run_des_sys_param(feature_geojson, scenario_csv):
             '"{tn_exe}" -y "{sp_file}" -s "{scenario}" -f "{feature}" -o {out_p}'.format(
                 tn_exe=tn_exe, sp_file=sys_param_file,
                 scenario=scn_dir, feature=feature_geojson, out_p=ghe_dir)
+        print(build_cmd)
         process = subprocess.Popen(
             build_cmd, stderr=subprocess.PIPE, shell=False, env=PYTHON_ENV
         )
@@ -602,22 +610,6 @@ def run_des_sys_param(feature_geojson, scenario_csv):
         if 'ValueError' in stderr_str:  # pass the exception onto the user
             msg = stderr_str.split('ValueError: ')[-1].strip()
             raise ValueError(msg)
-        # add the borehole length and count to the system parameter file
-        with open(sys_param_file, 'r') as spf:
-            sp_dict = json.load(spf)
-        ghe_par_dict = sp_dict['district_system']['fifth_generation']['ghe_parameters']
-        for ghe_s_par, rect_par in zip(ghe_par_dict['ghe_specific_params'], rect_geo_par):
-            r_dir = des_par['ghe_parameters']['ghe_dir']
-            res_file = os.path.join(r_dir, ghe_s_par['ghe_id'], 'SimulationSummary.json')
-            with open(res_file, 'r') as rf:
-                res_dict = json.load(rf)
-            ghe_s_par['borehole']['length_of_boreholes'] = \
-                res_dict['ghe_system']['active_borehole_length']['value']
-            ghe_s_par['borehole']['number_of_boreholes'] = \
-                res_dict['ghe_system']['number_of_boreholes']
-            ghe_s_par['ghe_geometric_params'] = rect_par
-        with open(sys_param_file, 'w') as spf:
-            json.dump(sp_dict, spf, indent=2)
     return sys_param_file
 
 
